@@ -167,6 +167,9 @@ INTERNALERROR = 'InternalError'
 # API网关内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_APIGWEXCEPTION = 'InternalError.ApigwException'
 
+# CAM内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
+INTERNALERROR_CAMEXCEPTION = 'InternalError.CamException'
+
 # CAuth内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_CAUTHEXCEPTION = 'InternalError.CauthException'
 
@@ -248,6 +251,9 @@ INVALIDPARAMETERVALUE_INVALIDGENLANGUAGE = 'InvalidParameterValue.InvalidGenLang
 # 参数后端地址取值错误。
 INVALIDPARAMETERVALUE_INVALIDIPADDRESS = 'InvalidParameterValue.InvalidIPAddress'
 
+# 参数请求配额总数取值错误。
+INVALIDPARAMETERVALUE_INVALIDMAXREQUESTNUM = 'InvalidParameterValue.InvalidMaxRequestNum'
+
 # 方法错误。仅支持 ANY, BEGIN, GET, POST, DELETE, HEAD, PUT, OPTIONS, TRACE, PATCH，请修改后重新操作。
 INVALIDPARAMETERVALUE_INVALIDMETHOD = 'InvalidParameterValue.InvalidMethod'
 
@@ -326,6 +332,9 @@ INVALIDPARAMETERVALUE_PARAMETERVALUELIMITEXCEEDED = 'InvalidParameterValue.Param
 # 参数取值错误，不在参数范围内。
 INVALIDPARAMETERVALUE_RANGEEXCEEDED = 'InvalidParameterValue.RangeExceeded'
 
+# 参数取值错误。
+INVALIDPARAMETERVALUE_UNSUPPORTEDPARAMETER = 'InvalidParameterValue.UnsupportedParameter'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -443,6 +452,9 @@ UNSUPPORTEDOPERATION_ACCOUNTARREARS = 'UnsupportedOperation.AccountArrears'
 # 密钥已绑定使用计划。
 UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsagePlan'
 
+# API列表不为空
+UNSUPPORTEDOPERATION_APILISTNOTEMPTY = 'UnsupportedOperation.ApiListNotEmpty'
+
 # 当前插件不支持绑定。
 UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
 
@@ -452,6 +464,9 @@ UNSUPPORTEDOPERATION_BASICSERVICENOMOREAPI = 'UnsupportedOperation.BasicServiceN
 # 日志检索起始时间间隔。
 UNSUPPORTEDOPERATION_CLSSEARCHTIME = 'UnsupportedOperation.ClsSearchTime'
 
+# 存在现网环境
+UNSUPPORTEDOPERATION_EXISTINGONLINEENVIRONMENT = 'UnsupportedOperation.ExistingOnlineEnvironment'
+
 # 协议为HTTP时，不支持强制Https。
 UNSUPPORTEDOPERATION_FORCEHTTPS = 'UnsupportedOperation.ForceHttps'
 
@@ -494,9 +509,15 @@ UNSUPPORTEDOPERATION_RESOURCEISINUSE = 'UnsupportedOperation.ResourceIsInUse'
 # 资源未关联。
 UNSUPPORTEDOPERATION_RESOURCEUNASSOCIATED = 'UnsupportedOperation.ResourceUnassociated'
 
+# 标签不为空
+UNSUPPORTEDOPERATION_TAGSNOTEMPTY = 'UnsupportedOperation.TagsNotEmpty'
+
 # 当前Uin未在手工密钥白名单列表内。
 UNSUPPORTEDOPERATION_UINNOTINWHITELIST = 'UnsupportedOperation.UinNotInWhiteList'
 
+# Unpack函数错误
+UNSUPPORTEDOPERATION_UNPACKERROR = 'UnsupportedOperation.UnpackError'
+
 # 密钥已绑定使用计划。
 UNSUPPORTEDOPERATION_UNSUPPORTEDBINDAPIKEY = 'UnsupportedOperation.UnsupportedBindApiKey'
 
